<?php /**
* domains Class
*
* Contains all the specific functions of managing domains
*
* @package Maarch LetterBox 2.4
* @version 2.1
* @since 06/2007
* @license GPL
* @author  Claire Figueras  <dev@maarch.org>
* @author  Loic Vinet <dev@maarch.org>
* @author  Laurent Giovannoni <dev@maarch.org>
*/
class domain extends dbquery
{
	/**
	*
	* @access private
	* @var integer
	*/
	private $the_start;

	/**
	* Redefinition of the LetterBox object constructor
	*/
	function __construct()
	{
		// configure the sql argument order by
		if(isset($_GET['start']))
		{
			$this->the_start = strip_tags($_GET['start']);
		}
		else
		{
			$this->the_start = 0;
		}
	}
	
	/**
	* Alphabetical list of the domains
	*
	* @param string  $page  page name
	*/
	public function domainslistletters($page = "domains")
	{
		// List all the alphabet letter to view the doc types who are starting with the letter
		if(isset($_GET['show']))
		{
			if($_GET['show'] == "false")
			{
				$show = "&show=false";
			}
			else
			{
				$show = "";
			}
		}
		else
		{
			$show = "";
		}
		?>
		<form action="index.php" method="get" name="frmletters" id="frmletters">
			<fieldset>
				<p>
					<input name="what" type="text" class="textbox medium" value="" />
					<input name="Submit" type="submit" value="<?php echo _SEARCH; ?>" class="button" />
					<input name="page" type="hidden" value="<?php echo $page; ?>" />
					<?php if($show == "&show=false") { ?><input name="show" type="hidden" value="false" /><?php } ?>
				</p>
			</fieldset>
			<p>
				<strong><?php echo _ALPHABETICAL_LIST; ?></strong> : 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=A">A</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=B">B</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=C">C</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=D">D</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=E">E</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=F">F</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=G">G</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=H">H</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=I">I</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=J">J</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=K">K</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=L">L</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=M">M</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=N">N</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=O">O</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=P">P</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=Q">Q</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=R">R</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=S">S</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=T">T</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=U">U</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=V">V</a> 
				<a href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=W">W</a> 
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=X">X</a>
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=Y">Y</a>
				<a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>&amp;what=Z">Z</a>
				- <a  href="index.php?page=<?php echo $page; ?><?php echo $show; ?>"><?php echo _ALL_DOMAINS;?></a>
			</p>
		</form>
		<?php }
	
	/**
	* List of domains
	*
	* @param string  $where $where clause
	* @param string  $what sort info
	*/
	public function domainslist($where = "",$what = "")
	{
		// draw the domains list
		$func = new functions();
		
		/* Configuration */
		$title = _DOMAINS_LIST;
		$page_name = "domains";
		$table_name = $_SESSION['tablename']['domains'];
		$res_table = "res_x";
		$nb_show = $_SESSION['config']['nblinetoshow'];
		
		if(!empty($what))
		{
			$what = "&what=".$what;
		}
		
		if(!empty($where))
		{
			$where = " where ".$where;
		}
		/***********************/
		
		$this->connect();
		$this->query("select count(*) as total from ".$table_name." ".$where);
		$nb_total_1 = $this->fetch_object();
		$nb_total = $nb_total_1->total;
		
		// define the defaults values
		$nb_pages = ceil($nb_total/$nb_show);
		
		$link = "index.php?page=".$page_name."&start=".$this->the_start."&order=".$this->orderby.$what;
		
		if($nb_pages > 1)
		{
			$next_start = 0;
			
			$page_list1 = '<form name="newpage1" id="newpage1" method="get" action="index.php?page=groups" >
			<p>
				<label for="startpage">'._GO_TO_PAGE.'</label>
				<select name="startpage" id="startpage" class="textbox small" onchange="window.location.href=\''.$link.'&amp;start=\'+document.newpage1.startpage.value;">';
			
			$page_list2 = '<form name="newpage2" id="newpage2" method="get" action="index.php?page=groups"  >
			<p>
				<label for="startpage">'._GO_TO_PAGE.'</label>
				<select name="startpage" id="startpage" class="textbox small" onchange="window.location.href=\''.$link.'&amp;start=\'+document.newpage2.startpage.value;">';
			
			$lastpage = 0;
			
			for($i = 0;$i <> $nb_pages; $i++)
			{
				$page_name = $i + 1;
				
				$the_line = $i + 1;
				if($this->the_start == $next_start)
				{
					$page_list1 .= "<option value=\"".$next_start."\" selected=\"selected\">".$the_line."</option>";
					$page_list2 .= "<option value=\"".$next_start."\" selected=\"selected\">".$the_line."</option>";
				}
				else
				{
					$page_list1 .= "<option value=\"".$next_start."\">".$the_line."</option>";
					$page_list2 .= "<option value=\"".$next_start."\">".$the_line."</option>";
				}
				
				$next_start = $next_start + $nb_show;
				$lastpage = $next_start;
			}
			
			$lastpage = $lastpage - $nb_show;
			
			$previous = "";
			$next = "";
			
			if($this->the_start > 0)
			{
				$start_prev = $this->the_start - $nb_show;
				$previous = '<a href="'.$link.'&amp;start='.$start_prev.'" class="prev">'._PREVIOUS.'</a>';
			}
			
			if($this->the_start <> $lastpage)
			{
				$start_next = $this->the_start + $nb_show;
				$next = '<a href="'.$link.'&amp;start='.$start_next.'" class="next">'._NEXT.'</a>';
			}
			
			$page_list1 = $page_list1."</select>";
			$page_list2 = $page_list2."</select>";
				
			if($previous <> '' || $next <> '')
			{
				if(empty($previous)) { $previous = "&nbsp;"; }
				if(empty($next)) { $next = "&nbsp;"; }
				
				$page_list1 .= $previous." ".$next.'</p></form>';
				$page_list2 .= $previous." ".$next.'</p></form>';
			}
		}
		
		$this->query("select distinct ID from ".$table_name." ".$where." order by label asc limit ".$this->the_start.",".$nb_show);
			
			echo '<h1><img src="'.$_SESSION['config']['img'].'/picto_types_b.gif" alt="" /> '.$title.'</h1>
		
			<div id="inner_content" class="clearfix">';
			
		$this->domainslistletters();
		 echo $page_list1; 
		?>
		<table cellpadding="0" cellspacing="0" border="0" class="listing spec">
			<thead>
				<tr>
					<th class="title"><?php echo _ID;?> </th>
					<th class="id"><?php echo _WORDING;?></th>
					<th colspan="3" align="right" class="price"><span class="add clearfix"><a  href="index.php?page=domain_add"  ><span><?php echo _ADD_DOMAIN;?></span></a></span></th>
			  </tr>
			</thead>
			<tfoot>
				<tr>
					<td colspan="7" class="price"><span class="add clearfix"><a  href="index.php?page=domain_add"  ><span><?php echo _ADD_DOMAIN;?></span></a></span></td>
				</tr>
			</tfoot>
			<tbody>
				<?php $db = new dbquery();
				$db->connect();
				$color = "line1";
				while($line = $this->fetch_object())
				{
					if($color == ' class="col"')
					{
						$color = '';
					}
					else
					{
						$color = ' class="col"';
					}
					$db->query("select ID, LABEL from ".$table_name." where ID ='".$line->ID."'"); 		
					$desc = "";
					$line2 = $db->fetch_object();
					$desc = $line2->LABEL;
					?>
					<tr <?php echo $color; ?>>
						<td class="id"><strong><?php echo $line->ID; ?></strong></td>
						<td class="id"><strong><?php echo $desc; ?></strong></td>
						<td class="action">
							<a href="index.php?page=domain_up&amp;id=<?php echo $line->ID;?>" class="change"><?php echo _MODIFY; ?></a>
		                </td>
						<td class="action">
							<a href="domain_del.php?id=<?php echo $line->ID;?>" class="delete" onClick="return(confirm('<?php echo ' '._REALLY_DELETE.' '.$line2->LABEL.' ('.$line->ID.') ?\n'._DEFINITIVE_ACTION."!";?>'));" ><?php echo _DELETE;?></a>
						</td>	
					</tr>
					<?php }
				?>
			</tbody>
		</table>
		</div>

		<?php $this->cleardomaininfos();
		$_SESSION['services'] = array();
		$this->query("select ID, SERVICE from ".$_SESSION['tablename']['services']." where ENABLED = 'Y'");
		
		while($line = $this->fetch_object())
		{
			array_push($_SESSION['services'], array("ID"=>$line->ID, "LABEL" => $line->SERVICE)); 
		}
		$_SESSION['chosen_services'] = array();
	}
	
	/**
	* Clear the session variables of the domain administration
	*
	*/
	private function cleardomaininfos()
	{
		// clear the session variable for the domains
		$_SESSION['m_admin']['domain'] = array();
		$_SESSION['m_admin']['domain']['ID'] = "";
		$_SESSION['m_admin']['domain']['LABEL'] = "";
		$_SESSION['m_admin']['domain']['SERVICES'] = array();
	}
	
	/**
	* Form to add or modify a domain
	*
	* @param string  $mode  up or add
	* @param string  $id  identifier of the domain to modify
	*/
	public function formdomain($mode,$id = "")
	{
		$func = new functions();
		$state = true;
		if(!isset($_SESSION['m_admin']['domain']))
		{
			$this->cleardomaininfos();
		}
		if($mode <> "add" && empty($_SESSION['error']))
		{
			$this->connect();
			$this->query("select * from ".$_SESSION['tablename']['domains']." where ID = '".$id."'");
			if($this->nb_result() == 0)
			{
				$_SESSION['error'] = _DOMAIN.' '._UNKNOWN;
				$state = false;
			}
			else
			{
				$_SESSION['m_admin']['domain'] = array();
				$line = $this->fetch_object();
				$_SESSION['m_admin']['domain']['ID'] = $line->ID;
				$_SESSION['m_admin']['domain']['LABEL'] = trim($line->LABEL);
				$_SESSION['m_admin']['domain']['SERVICES'] = array();
				$this->query("select s.ID, s.SERVICE from ".$_SESSION['tablename']['domain_service']." ms, ".$_SESSION['tablename']['services']." s where ms.ID_DOMAIN = ".$_SESSION['m_admin']['domain']['ID']." and s.ID = ms.ID_SERVICE");
				//$this->show();
				while($res = $this->fetch_object())
				{
					array_push($_SESSION['m_admin']['domain']['SERVICES'] , array('ID' =>$res->ID, 'LABEL' => $res->SERVICE));
				}
	
			}
		}
		?>
		<h1><img src="<?php echo $_SESSION['config']['img'];?>/picto_add_b.gif" alt="" /> 
			<?php if($mode == "up")
			{
				echo _DOMAIN_MODIFICATION;
			}
			elseif($mode == "add")
			{
				echo _DOMAIN_ADDITION;
			}
			?>
		</h1>
		<div id="inner_content" class="clearfix">
			<?php if($state == false)
			{
				?>
            	<script language="javascript" type="text/javascript">window.document.location.href = 'index.php?page=domains';</script>
				<?php }
			else
			{
				?>
				<form name="frmdomain" id="frmdomain" method="post" action="domain_up_db.php" class="forms">
				<input type="hidden" name="mode" id="mode" value="<?php echo $mode;?>" />		
					<?php if($mode == "up")
					{
						?>
						<input  type="hidden" name="domain_id" id="domain_id" value="<?php echo $_SESSION['m_admin']['domain']['ID']; ?>"/>
						<?php }
					?>
					<p>
						<label><?php echo _WORDING;?> :</label>
						<input type="text" name="domain_name" id="domain_name" value="<?php echo $_SESSION['m_admin']['domain']['LABEL'];?>"/><span class="red_asterisk">*</span>
					</p>
					<div align="center">
						<iframe align="middle" name="associated_domain_services" id="associated_domain_services" src="associated_domain_services.php" frameborder="0" height="180px" width="500px;"></iframe>
					</div>
					<p class="buttons">
						<input type="submit" class="button"  name="Submit" value="<?php echo _VALIDATE; ?>" />
						<input type="button" onClick="javascript:window.location.href='index.php?page=domains';" class="button"  name="cancel" value="<?php echo _CANCEL; ?>" />
					</p>
				</form>
				<?php }
			?>
		</div>
		<?php }
	
	/**
	* Verify the domain informations
	*
	*/
	private function domaininfo()
	{		
		$func = new functions();
		if(!isset($_REQUEST['mode']))
		{
			$_SESSION['error'] = _UNKNOWN_PARAM."<br />";
		}
		$_SESSION['m_admin']['domain']['LABEL'] = $func->wash($_REQUEST['domain_name'], "no", _THE_WORDING);
		$_SESSION['m_admin']['domain']['LABEL'] = trim(stripslashes($_SESSION['m_admin']['domain']['LABEL']));
		if($_REQUEST['mode'] == "up")
		{
			$_SESSION['m_admin']['domain']['ID'] = $func->wash($_REQUEST['domain_id'], "no", _ID);
		}
	}
	/**
	* Update the database with the domain data
	*
	*/
	public function updomain()
	{
		$this->domaininfo();
		if(!empty($_SESSION['error']))
		{
			if($_REQUEST['mode'] == "up")
			{
				if(!empty($_SESSION['m_admin']['domain']['ID']))
				{
					header("location: index.php?page=domain_up&id=".$_SESSION['m_admin']['label']['ID']);
					exit;
				}
				else
				{
					header("location: index.php?page=domains");
					exit;
				}
			}
			elseif($_REQUEST['mode'] == "add" )
			{
				header("location: index.php?page=domain_add");
				exit;
			}
		}
		else
		{
			$this->connect();
			if( $_REQUEST['mode'] <> "add")
			{
				
				$this->query("update `".$_SESSION['tablename']['domains']."` set LABEL = '".addslashes($_SESSION['m_admin']['domain']['LABEL'])."' where ID = '".$_SESSION['m_admin']['domain']['ID']."'");
				$this->query("delete from ".$_SESSION['tablename']['domain_service']." where ID_DOMAIN = '".$_SESSION['m_admin']['domain']['ID']."'");				
				for($i=0; $i < count($_SESSION['m_admin']['domain']['SERVICES']);$i++)
				{
					$this->query("insert into ".$_SESSION['tablename']['domain_service']." ( ID_SERVICE, ID_DOMAIN  ) VALUES ( '".$_SESSION['m_admin']['domain']['SERVICES'][$i]['ID']."', ".$_SESSION['m_admin']['domain']['ID'].")");
				}
				if($_REQUEST['mode'] == "up")
				{
					$_SESSION['error'] = _DOMAIN_MODIFICATION;
					if($_SESSION['history']['domainsup'] == "true")
					{
						require_once("class_history.php");
						$users = new history();
						$users->add($_SESSION['tablename']['domains'], $_SESSION['m_admin']['domain']['ID'],"UP",_DOMAIN_MODIFICATION." : ".$_SESSION['m_admin']['domain']['LABEL']);
					}
				}
				$this->cleardomaininfos();
				header("location: index.php?page=domains");
				exit;
			}
			else
			{
				$this->query("select LABEL from ".$_SESSION['tablename']['domains']." where LABEL = '".addslashes($_SESSION['m_admin']['domain']['LABEL'])."'");
				if($this->nb_result() > 0)
				{
					$_SESSION['error'] = _THE_DOMAIN.' '.$_SESSION['m_admin']['domain']['LABEL'].' '._ALREADY_EXISTS;
					header("location: index.php?page=domain_add");
					exit;
				}
				else
				{
					require_once("class_history.php");
					$users = new history();
					if( $_REQUEST['mode'] == "add")
					{
						$this->query("INSERT INTO ".$_SESSION['tablename']['domains']." (LABEL) VALUES('".addslashes($_SESSION['m_admin']['domain']['LABEL'])."')");
						$this->query("select ID from ".$_SESSION['tablename']['domains']." where LABEL = '".addslashes($_SESSION['m_admin']['domain']['LABEL'])."'");
						$res = $this->fetch_object();
						$_SESSION['m_admin']['domain']['ID'] = $res->ID;
						if($_SESSION['history']['domainsadd'] == "true")
						{
							$users->add($_SESSION['tablename']['domains'], $_SESSION['m_admin']['domain']['ID'],"ADD", _DOMAIN_ADDED." : ".$_SESSION['m_admin']['domain']['LABEL']);
						}
					}
					for($i=0; $i < count($_SESSION['m_admin']['domain']['SERVICES']);$i++)
					{
						$this->query("insert into ".$_SESSION['tablename']['domain_service']." (ID_DOMAIN, ID_SERVICE) VALUES (".$_SESSION['m_admin']['domain']['ID'].", '".$_SESSION['m_admin']['domain']['SERVICES'][$i]['ID']."' )");
					}
					$_SESSION['error'] = _DOMAIN_ADDED;
				}
				$_SESSION['error'] = "";
			}
			if ($_REQUEST['mode'] == "add")
			{
				$url = "index.php?page=domains";
			}
			$this->cleardomaininfos();
			header("location: ".$url);
			exit;
		}
	}
	
	/**
	* delete a domain in the database
	*
	* @param string $id domain identifier
	*/
	public function deldomain($id)
	{
		if(!empty($_SESSION['error']))
		{
			header("location: index.php?page=domains");
			exit;
		}
		else
		{
			$this->connect();
			$this->query("select ID, LABEL from ".$_SESSION['tablename']['domains']." where ID = ".$id);		
			if($this->nb_result() == 0)
			{
				$_SESSION['error'] = _DOMAIN.' '._UNKNOWN;
				header("location: index.php?page=domains");
				exit;
			}
			else
			{
				$res = $this->fetch_object();
				$label = $res->LABEL;
				$this->query("delete from ".$_SESSION['tablename']['domains']." where ID = ".$id);
				$this->query("delete from ".$_SESSION['tablename']['domain_service']." where ID_DOMAIN = ".$id);
				if($_SESSION['history']['domainsdel'])
				{
					require_once("class_history.php");
					$users = new history();
					$users->add($_SESSION['tablename']['domains'], $id,"DEL",_DOMAIN_DELETION." : ".$label);
				}
				$_SESSION['error'] = _DELETED_DOMAIN;	
				header("location: index.php?page=domains");
				exit;	
			}
		}
	}
	
	/**
	* get domain for one service (if filled)
	*
	* @param string $service_id service identifier
	*/
	public function get_domains($service_id='')
	{
		if (!empty ($service_id))
		{
			if (is_array($service_id))
			{
				$my_services = array();
				
				foreach($service_id as $theService)
				{
					$my_services[] = "'".$theService."'";
				}
				
				$where = "where ID_SERVICE in (".join(",", $my_services).")";
				$grouby = "group by ID_DOMAIN";
			}
			else
			{
				$where = "where ID_SERVICE = '".$service_id."'";
			}
			
		}
		
		$domains = array();
		
		$db = new dbquery();
		$db->connect();
					
		$db2 = new dbquery();
		$db2->connect();
		
		$db->query("select ID_SERVICE, ID_DOMAIN from ".$_SESSION['tablename']['domain_service']." ".$where." ".$grouby." order by ID_SERVICE asc ");
		//$db->show();
		$actual_service = $save_service = '';
		
		while($res = $db->fetch_object())
		{
			$db2->query("select ID, LABEL from ".$_SESSION['tablename']['domains']." where ID = ".$res->ID_DOMAIN);
			$res2 = $db2->fetch_object();
			
			$domains[$res->ID_SERVICE][] = array('ID' =>$res2->ID, 'LABEL' => $res2->LABEL);
		}
		
		return $domains;
	}
	
	public function get_domain_label($domain_id)
	{
		$label = '';
		
		if (!empty ($domain_id))
		{
			$this->connect();
			$this->query("select LABEL from ".$_SESSION['tablename']['domains']." where ID = ".$domain_id);
			$res = $this->fetch_object();
			$label = $res->LABEL;
		}
		
		return $label;
	}
}
?>
