<?php /**
*  Usergroups class
*
* Contains all the functions to manage the groups 
*
* @package Maarch LetterBox 2.3
* @version 2.2
* @since 06/2006
* @license GPL
* @author  Claire Figueras  <dev@maarch.org>
* 
*/

/**
* Class usergroups: contains all the functions and forms to manage the usergroups
*
* @author  Claire Figueras  <dev@maarch.org>
* @license GPL
* @package Maarch LetterBox 2.3
* @version 2.2
*/

class usergroups extends dbquery
{
	/**
    * @access private
    * @var integer
    */
	private $the_start;
	
	
	/**
	* Redefinition of the user object constructor : configure the SQL argument order by
	*/
	function __construct()
	{
		// configure the sql argument order by
		if(isset($_GET['start']))
		{
			$this->the_start = strip_tags($_GET['start']);
		}
		else
		{
			$this->the_start = 0;
		}
	}
	
	/**
	* Lists the letters of the alphabet to list the groups
	*/
	public function groupslistletters()
	{
		?>
		<form action="index.php" name="frmletters" id="frmletters" class="smallforms" method="get">
			<fieldset>
				<p>
					<input name="what" id="what" type="text" class="textbox medium" value="" />
					<input name="Submit" type="submit" value="<?php echo _SEARCH.' '._GROUP ; ?>" class="button" />
					<input name="page" type="hidden" value="groups" />
				</p>
			</fieldset>
			<p><strong><?php echo _ALPHABETICAL_LIST; ?></strong> : 
				<a href="index.php?page=groups&amp;what=A">A</a> 
				<a href="index.php?page=groups&amp;what=B">B</a> 
				<a href="index.php?page=groups&amp;what=C">C</a> 
				<a href="index.php?page=groups&amp;what=D">D</a> 
				<a href="index.php?page=groups&amp;what=E">E</a> 
				<a href="index.php?page=groups&amp;what=F">F</a> 
				<a href="index.php?page=groups&amp;what=G">G</a> 
				<a href="index.php?page=groups&amp;what=H">H</a> 
				<a href="index.php?page=groups&amp;what=I">I</a> 
				<a href="index.php?page=groups&amp;what=J">J</a> 
				<a href="index.php?page=groups&amp;what=K">K</a> 
				<a href="index.php?page=groups&amp;what=L">L</a> 
				<a href="index.php?page=groups&amp;what=M">M</a> 
				<a href="index.php?page=groups&amp;what=N">N</a> 
				<a href="index.php?page=groups&amp;what=O">O</a> 
				<a href="index.php?page=groups&amp;what=P">P</a> 
				<a href="index.php?page=groups&amp;what=Q">Q</a> 
				<a href="index.php?page=groups&amp;what=R">R</a> 
				<a href="index.php?page=groups&amp;what=S">S</a> 
				<a href="index.php?page=groups&amp;what=T">T</a> 
				<a href="index.php?page=groups&amp;what=U">U</a> 
				<a href="index.php?page=groups&amp;what=V">V</a> 
				<a href="index.php?page=groups&amp;what=W">W</a> 
				<a href="index.php?page=groups&amp;what=X">X</a>
				<a href="index.php?page=groups&amp;what=Y">Y</a>
				<a href="index.php?page=groups&amp;what=Z">Z</a>
				- <a href="index.php?page=groups"><?php echo _ALL_GROUPS; ?></a></p>
			</form>
		<?php }
	
	/**
	* Shows the list of the groups according to the selected letter.
	*
	* @param 	string  $where sorting of the list (empty by default)
	* @param 	string  $what  first letter of the name (empty by default)
	*/
	public function groupslist($where = "",$what = "")
	{
		// draw the groups list
		$func = new functions();
		
		/* Configuration */
		/* Just edit this part */
		$title = _GROUPS_LIST;
		$page_name = "groups";
		$page_name_up = "group_up";
		$page_name_del = "group_del";
		$page_name_validate= "group_allow";
		$page_name_ban = "group_ban";
		$table_name = $_SESSION['tablename']['usergroups'];
		$nb_show = $_SESSION['config']['nblinetoshow'];
		
		$_SESSION['m_admin']['load_security']  = true;
		$_SESSION['m_admin']['init'] = true;
		if(!empty($what))
		{
			$what = "&amp;what=".$what;
		}
		/***********************/
		
		$this->connect();
		
		$_SESSION['m_admin']['services'] = array();
		
		$this->query("select * from ".$_SESSION['tablename']['services']." WHERE ENABLED = 'Y' order by SERVICE ");
		
		while($line = $this->fetch_object())
		{
			array_push($_SESSION['m_admin']['services'], array( "ID" => $line->ID, "COMMENT" => $line->SERVICE));
		}
		
		$this->query("select count(*) as total from ".$table_name);
		$nb_total_1 = $this->fetch_object();
		$nb_total = $nb_total_1->total;
		
		// define the defaults values
		$nb_pages = ceil($nb_total/$nb_show);
		
		$link = "index.php?page=".$page_name."&amp;start=".$this->the_start."&amp;order=".$this->orderby.$what;
		
		if($nb_pages > 1)
		{
			$next_start = 0;
			
			$page_list1 = '<form name="newpage1" id="newpage1" method="get" action="index.php?page=groups" >
			<p>
				<label for="startpage">'._GO_TO_PAGE.'</label>
				<select name="startpage" id="startpage" class="textbox small" onchange="window.location.href=\''.$link.'&amp;start=\'+document.newpage1.startpage.value;">';
			
			$page_list2 = '<form name="newpage2" id="newpage2" method="get" action="index.php?page=groups"  >
			<p>
				<label for="startpage">'._GO_TO_PAGE.'</label>
				<select name="startpage" id="startpage" class="textbox small" onchange="window.location.href=\''.$link.'&amp;start=\'+document.newpage2.startpage.value;">';
			
			$lastpage = 0;
			
			for($i = 0;$i <> $nb_pages; $i++)
			{
				$page_name = $i + 1;
				
				$the_line = $i + 1;
				if($this->the_start == $next_start)
				{
					$page_list1 .= "<option value=\"".$next_start."\" selected=\"selected\">".$the_line."</option>";
					$page_list2 .= "<option value=\"".$next_start."\" selected=\"selected\">".$the_line."</option>";
				}
				else
				{
					$page_list1 .= "<option value=\"".$next_start."\">".$the_line."</option>";
					$page_list2 .= "<option value=\"".$next_start."\">".$the_line."</option>";
				}
				
				$next_start = $next_start + $nb_show;
				$lastpage = $next_start;
			}
			
			$lastpage = $lastpage - $nb_show;
			
			$previous = "";
			$next = "";
			
			if($this->the_start > 0)
			{
				$start_prev = $this->the_start - $nb_show;
				$previous = '<a href="'.$link.'&amp;start='.$start_prev.'" class="prev">'._PREVIOUS.'</a>';
			}
			
			if($this->the_start <> $lastpage)
			{
				$start_next = $this->the_start + $nb_show;
				$next = '<a href="'.$link.'&amp;start='.$start_next.'" class="next">'._NEXT.'</a>';
			}
			
			$page_list1 = $page_list1."</select>";
			$page_list2 = $page_list2."</select>";
				
			if($previous <> '' || $next <> '')
			{
				if(empty($previous)) { $previous = "&nbsp;"; }
				if(empty($next)) { $next = "&nbsp;"; }
				
				$page_list1 .= $previous." ".$next.'</p></form>';
				$page_list2 .= $previous." ".$next.'</p></form>';
			}
		}
		
		$this->query("select * from ".$table_name." ".$where." order by GROUP_DESC asc limit ".$this->the_start.",".$nb_show);
		
		echo '<h1><img src="'.$_SESSION['config']['img'].'/picto_group_b.gif" alt="" /> '.$title.'</h1>
		
			<div id="inner_content" class="clearfix">';
		
		$this->groupslistletters();
		 echo $page_list1; 
		?>
		
			<table cellpadding="0" cellspacing="0" border="0" class="listing spec">
				<thead>
					<tr>
						<th><?php echo _GROUP; ?></th>
						<th class="title"><?php echo _DESC; ?></th>
						<th class="ged"><?php echo _ADMIN_GROUP; ?></th>
						<th></th>
						<th colspan="2" class="price"><span class="add clearfix"><a href="index.php?page=group_add"><span><?php echo _ADD_GROUP; ?></span></a></span></th>
					</tr>
				</thead>
				<tfoot>
					<tr>
						<td colspan="6" class="price"><span class="add clearfix"><a href="index.php?page=group_add"><span><?php echo _ADD_GROUP; ?></span></a></span></td>
					</tr>
				</tfoot>
				<tbody>
		<?php $color = ' class="col"';
		while($line = $this->fetch_object())
		{
			if($color == ' class="col"')
			{
				$color = '';
			}
			else
			{
				$color = ' class="col"';
			}
			
			?>
					<tr<?php echo $color; ?>>
						<td><?php echo $line->GROUP_ID; ?></td>
						<td class="title"><?php echo str_replace('\\', '',$line->GROUP_DESC); ?> </td>
						<td class="ged"><?php if($line->ADMINISTRATOR == 'Y')
						{
							echo _YES;
						}
						else
						{
							echo _NO;
						}
					 ?> </td>
					<td class="action">
						<?php if($line->ENABLED == "Y" && $line->GROUP_ID <> "Administrators") {
							echo '<a href="index.php?page=group_up&amp;id='.$line->GROUP_ID.'" class="change">'._MODIFY.'</a>';
						} ?>
					 </td>
					<td class="action">
					<?php if($line->ENABLED == "N") {
						echo '<a href="'.$page_name_validate.'.php?id='.$line->GROUP_ID.'" onclick="return(confirm(\''._REALLY_AUTHORIZE.' '.$line->GROUP_ID.' ?\'));" class="authorize">'._AUTHORIZE.'</a>';
					}
					else {
						if($line->GROUP_ID <> "Administrators") {
								echo '<a href="'.$page_name_ban.'.php?id='.$line->GROUP_ID.'" onclick="return(confirm(\''._REALLY_SUSPEND.' '.$line->GROUP_ID.' ?\'));" class="suspend">'._SUSPEND.'</a>';
						}
					}					
					?>	
					</td>
					<td class="action">
					<?php if($line->GROUP_ID <> "Administrators") {
						echo '<a href="'.$page_name_del.'.php?id='.$line->GROUP_ID.'" onclick="return(confirm(\''._REALLY_DELETE.$line->GROUP_ID.' ?\n'._DEFINITIVE_ACTION.'.\'));" class="delete">'._DELETE.'</a>';
					}
					?>
					</td>
				</tr>
			<?php } ?>
			</tbody>
		</table>
		</div>
		
		<?php $_SESSION['m_admin']['groups'] = array();
		$_SESSION['m_admin']['groups']['GroupId'] = "";
		$_SESSION['m_admin']['groups']['desc'] = "";
		$_SESSION['m_admin']['groups']['admin'] = "";
		$_SESSION['m_admin']['groups']['security'] = array();
	}
	
	/**
	* Form for the management of the groups.
	*
	* @param 	string  $mode administrator mode (modification, suspension, authorization, delete)
	* @param 	string  $id  group identifier (empty by default)
	*/
	public function formgroups($mode,$id = "")
	{
		require_once("class_security.php");
		$sec = new security();
		
		$func = new functions();

		$state = true;
		//$_SESSION['services_choisis'] = array();
		
		if($mode == "up")
		{
			$_SESSION['m_admin']['mode'] = "up";
			if(empty($_SESSION['error']))
			{
				$this->connect();
				$this->query("select * from ".$_SESSION['tablename']['usergroups']." where group_id = '".$id."' and enabled = 'y'");
				
				if($this->nb_result() == 0)
				{
					$_SESSION['error'] = _NO_GROUP;
					$state = false;
				}
				else
				{
					$line = $this->fetch_object();
					
					$_SESSION['m_admin']['groups']['GroupId'] = $line->GROUP_ID;
					$_SESSION['m_admin']['groups']['desc'] = $line->GROUP_DESC;
					$_SESSION['m_admin']['groups']['desc'] = str_replace("\\", "", $_SESSION['m_admin']['groups']['desc']);
					$_SESSION['m_admin']['groups']['admin'] = $line->ADMINISTRATOR;
					$_SESSION['m_admin']['groups']['view_relance'] = $line->VIEW_RELANCE;
					$_SESSION['m_admin']['groups']['view_stats'] = $line->VIEW_STATS;
					$_SESSION['m_admin']['groups']['consult_group'] = $line->CONSULT_GROUP;
					$_SESSION['m_admin']['groups']['modif_rights'] = $line->MODIF_RIGHTS;
					$_SESSION['m_admin']['groups']['export'] = $line->EXPORT;
					$_SESSION['m_admin']['groups']['delete_rights'] = $line->DELETE_RIGHTS;
					$_SESSION['m_admin']['groups']['delete_copy_rights'] = $line->DELETE_COPY_RIGHTS;
					$_SESSION['m_admin']['groups']['delete_mail_actions_rights'] = $line->DELETE_MAIL_ACTIONS_RIGHTS;
					$_SESSION['m_admin']['groups']['folder_rights'] = $line->FOLDER_RIGHTS;
					$_SESSION['m_admin']['groups']['print_rights'] = $line->PRINT_RIGHTS;
					$_SESSION['m_admin']['groups']['print_sep_rights'] = $line->PRINT_SEP_RIGHTS;
					$_SESSION['m_admin']['groups']['close_rights'] = $line->CLOSE_RIGHTS;
					$_SESSION['m_admin']['groups']['mail_rights'] = $line->MAIL_RIGHTS;
					$_SESSION['m_admin']['groups']['reject_rights'] = $line->REJECT_RIGHTS;
					$_SESSION['m_admin']['groups']['def_reject_rights'] = $line->DEF_REJECT_RIGHTS;
					$_SESSION['m_admin']['groups']['validate_rights'] = $line->VALIDATE_RIGHTS;
					$_SESSION['m_admin']['groups']['attachment_rights'] = $line->ATTACHMENT_RIGHTS;
					$_SESSION['m_admin']['groups']['param'] = $line->PARAM;
					$_SESSION['m_admin']['groups']['gdd'] = $line->GDD;
				}
				
				if (! isset($_SESSION['m_admin']['load_security']) || $_SESSION['m_admin']['load_security'] == true)
				{
					$sec->load_security_group($id);
					$_SESSION['m_admin']['load_security'] = false ;
				}
				
			}
		}
		elseif($mode == "add")
		{
			$_SESSION['m_admin']['mode'] = "add";
			if ($_SESSION['m_admin']['init']== true || !isset($_SESSION['m_admin']['init'] ))
			{
				$sec->init_session();
			}
		}
		
		
		?>
	<h1><img src="<?php echo $_SESSION['config']['img'];?>/picto_add_b.gif" alt="" />
				
				<?php if($mode == "add")
				{
					echo _GROUP_ADDITION;
				}
				elseif($mode == "up")
				{
					echo _GROUP_MODIFICATION;
				}
				?>
				</h1>
		
			<?php if($state == false)
			{
				echo "<br /><br /><br /><br />"._GROUP.' '._UNKNOWN."<br /><br /><br /><br />";
			}
			else
			{
				?>
				<div id="inner_content" class="clearfix">
				<div id="group_box" class="bloc">
				<?php if($mode == "up")
						{
						?>
 							<a href="javascript://" onclick="window.open('liste_users.php?id=<?php echo $id;?>', '', 'scrollbars=yes,menubar=no,toolbar=no,resizable=yes,status=no,width=820,height=400')"><i><?php echo _SEE_GROUP_MEMBERS;?></i></a>
						<?php }?>
				<iframe name="group_form" id="group_form" class="frameform3" src="groups_form.php" frameborder="0" scrolling="auto"></iframe>
				</div>
				
				
				<form name="frmgroup" id="frmgroup" method="post" action="<?php if($mode == "up") { echo "group_up_db.php"; } elseif($mode == "add") { echo "group_add_db.php"; } ?>" class="forms addforms">
				<p>
					<label for="GroupId"><?php echo _ID; ?> :</label>
					<?php if($mode == "up") { echo $func->show($_SESSION['m_admin']['groups']['GroupId']); } ?>
					<input name="GroupId" class="medium" type="<?php if($mode == "up") { ?>hidden<?php } elseif($mode == "add") { ?>text<?php } ?>" id="GroupId" value="<?php echo $func->show($_SESSION['m_admin']['groups']['GroupId']); ?>" /><span class="red_asterisk">*</span>
					<input type="hidden" class="textbox" name="id" value="<?php echo $id; ?>" />
				</p>
				<p>
					<label for="desc"><?php echo _WORDING; ?> :</label>
					<input name="desc" id="desc" class="medium" type="text" value="<?php echo $_SESSION['m_admin']['groups']['desc']; ?>" /><span class="red_asterisk">*</span>
				</p>
				<p>
					<label for="admin"><?php echo _ADMIN_RIGHTS; ?> :</label>
					<input name="admin[]" id="admin2" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['admin'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _STATS_RIGHTS;?> :</label>
					<input name="stats[]" id="stats" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['view_stats'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<!--<p>
					<label for="admin"><?php echo _LATE_MAIL_RIGHTS;?> :</label>
					<input name="relance[]" id="relance" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['view_relance'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>-->	
				<p>
					<label for="admin"><?php echo _MODIF_RIGHTS;?> :</label>
					<input name="modif[]" id="modif" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['modif_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
                <p>
					<label for="admin"><?php echo _EXPORT_RIGHT;?> :</label>
					<input name="export[]" id="export" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['export'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
                <p>
					<label for="admin"><?php echo _CLOSE_RIGHTS;?> :</label>
					<input name="close[]" id="close" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['close_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				</p>
                <p>
					<label for="admin"><?php echo _DELETE_RIGHTS;?> :</label>
					<input name="delete[]" id="delete" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['delete_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _DELETE_COPY_RIGHTS;?> :</label>
					<input name="delete_copy[]" id="delete_copy" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['delete_copy_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _DELETE_MAIL_ACTIONS_RIGHTS;?> :</label>
					<input name="delete_mail_actions[]" id="delete_mail_actions" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['delete_mail_actions_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _PRINT_RIGHTS;?> :</label>
					<input name="print[]" id="print" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['print_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _PRINT_SEP_RIGHTS;?> :</label>
					<input name="separator[]" id="separator" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['print_sep_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>				
				<p>
					<label for="admin"><?php echo _ATTACHMENT_RIGHTS;?> :</label>
					<input name="attachment[]" id="attachment" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['attachment_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _MAIL_RIGHTS;?> :</label>
					<input name="mail[]" id="mail" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['mail_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _FOLDER_RIGHTS;?> :</label>
					<input name="folder[]" id="folder" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['folder_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _REJECT_RIGHTS;?> :</label>
					<input name="reject[]" id="mail" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['reject_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _DEF_REJECT_RIGHTS;?> :</label>
					<input name="defReject[]" id="mail" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['def_reject_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _VALIDATE_RIGHTS;?> :</label>
					<input name="validate[]" id="mail" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['validate_rights'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				<p>
					<label for="admin"><?php echo _PARAM_RIGHTS;?> :</label>
					<input name="param[]" id="param" class="check" type="checkbox" value="Y" <?php if ( $_SESSION['m_admin']['groups']['param'] == 'Y') { echo "checked=\"checked\"";} ?> />
				</p>
				
				
				<?php
				
				if($_SESSION['config']['gdd']=="true")
				{
					echo"
					<p>
						<label for=\"admin\">"._GDD." :</label>
						<input name=\"gdd[]\" id=\"gdd\" class=\"check\" type=\"checkbox\" value=\"Y\" "; if ( $_SESSION['m_admin']['groups']['gdd'] == 'Y') { echo "checked=\"checked\"";} echo" />
					</p>
					";				
				}
				
				?>
								
				
				<br/><br/>
				<p>
					<iframe src="consult_group.php" name="consult_group" id="consult_group" frameborder="0" scrolling="no" height="80" width="300" align="left"></iframe>
				</p>
			
				<p class="buttons">
				<input  type="submit"  name="Submit" value="<?php echo _VALIDATE; ?>" class="button"/>
                <input  type="button"  name="cancel" value="<?php echo _CANCEL; ?>" class="button" onclick="javascript:window.location.href='index.php?page=groups';"/>
						<?php /*	if($mode == "up")
						{
						?>
						<input id="groupbutton" type="submit"  name="Submit" value="<?php echo _MODIFY_GROUP; ?>" class="button"/>
						<?php }
						elseif($mode == "add")
						{
						?>
						<input type="submit" name="Submit" value="<?php echo _ADD_GROUP; ?>" class="button"/>
						<?php } */ ?>
				</p>
					<p>&nbsp;</p>
					<p>&nbsp;</p>	
			</form>	
		</div>

	<?php }
	}
	
	/**
	* Treats the information returned by the form of formgroups()
	*
	* @param 	string  $mode administrator mode (modification, suspension, authorization, delete)
	*/
	public function groupsinfo($mode)
	{
		$func = new functions();
		if(file_exists($_SESSION['config']['lang'].'.php'))
{
	include($_SESSION['config']['lang'].'.php');
}
else
{
	$_SESSION['error'] = "Language file missing...<br/>";
}	
		if($mode == "add")
		{
			$_SESSION['m_admin']['groups']['GroupId'] = $func->wash($_POST['GroupId'], "nick", _GROUP_ID);
		}
		
		if($mode == "up")
		{
			$_SESSION['m_admin']['groups']['GroupId'] = $func->wash($_POST['id'], "nick", _GROUP_ID);
		}
		
		$_SESSION['m_admin']['groups']['desc'] = $func->wash($_POST['desc'], "no", _GROUP_DESC);
		$_SESSION['m_admin']['groups']['desc'] = stripslashes($_SESSION['m_admin']['groups']['desc']);
		if (count($_POST['admin']) > 0 )
		{
			
			$_SESSION['m_admin']['groups']['admin'] = $_POST['admin'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['admin'] = 'N';
		}
		if (count($_POST['export']) > 0 )
		{
			
			$_SESSION['m_admin']['groups']['export'] = $_POST['export'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['export'] = 'N';
		}
	
		if (count($_POST['stats']) > 0 )
		{
			$_SESSION['m_admin']['groups']['view_stats'] = $_POST['stats'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['view_stats'] = 'N';
		}
	
		
		if (count($_POST['relance']) > 0 )
		{
			$_SESSION['m_admin']['groups']['view_relance'] = $_POST['relance'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['view_relance'] = 'N';
		}
	
		if (count($_POST['modif']) > 0 )
		{
		
			$_SESSION['m_admin']['groups']['modif_rights'] = $_POST['modif'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['modif_rights'] = 'N';
		}
		
		if (count($_POST['delete_mail_actions']) > 0 )
		{
		
			$_SESSION['m_admin']['groups']['delete_mail_actions_rights'] = $_POST['delete_mail_actions'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['delete_mail_actions_rights'] = 'N';
		}
		
		if (count($_POST['delete']) > 0 )
		{
		
			$_SESSION['m_admin']['groups']['delete_rights'] = $_POST['delete'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['delete_rights'] = 'N';
		}
		
		if (count($_POST['delete_copy']) > 0 )
		{
			$_SESSION['m_admin']['groups']['delete_copy_rights'] = $_POST['delete_copy'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['delete_copy_rights'] = 'N';
		}
		
		if (count($_POST['close']) > 0 )
		{
		
			$_SESSION['m_admin']['groups']['close_rights'] = $_POST['close'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['close_rights'] = 'N';
		}		
		if (count($_POST['mail']) > 0 )
		{
			$_SESSION['m_admin']['groups']['mail_rights'] = $_POST['mail'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['mail_rights'] = 'N';
		}
		if (count($_POST['folder']) > 0 )
		{
			$_SESSION['m_admin']['groups']['folder_rights'] = $_POST['folder'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['folder_rights'] = 'N';
		}
		if (count($_POST['reject']) > 0 )
		{
			$_SESSION['m_admin']['groups']['reject_rights'] = $_POST['reject'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['reject_rights'] = 'N';
		}
		if (count($_POST['defReject']) > 0 )
		{
			$_SESSION['m_admin']['groups']['def_reject_rights'] = $_POST['defReject'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['def_reject_rights'] = 'N';
		}
		if (count($_POST['validate']) > 0 )
		{
			$_SESSION['m_admin']['groups']['validate_rights'] = $_POST['validate'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['validate_rights'] = 'N';
		}
		if (count($_POST['print']) > 0 )
		{
		
			$_SESSION['m_admin']['groups']['print_rights'] = $_POST['print'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['print_rights'] = 'N';
		}		
		if (count($_POST['separator']) > 0 )
		{
			$_SESSION['m_admin']['groups']['print_sep_rights'] = $_POST['separator'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['print_sep_rights'] = 'N';
		}
		if (count($_POST['attachment']) > 0 )
		{
			$_SESSION['m_admin']['groups']['attachment_rights'] = $_POST['attachment'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['attachment_rights'] = 'N';
		}
		
		if (count($_POST['gdd']) > 0 )
		{
			$_SESSION['m_admin']['groups']['gdd'] = $_POST['gdd'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['gdd'] = 'N';
		}

		
		if (count($_POST['param']) > 0 )
		{
		
			$_SESSION['m_admin']['groups']['param'] = $_POST['param'][0];
		}
		else
		{
			$_SESSION['m_admin']['groups']['param'] = 'N';
		}
		
		if ( $_SESSION['m_admin']['groups']['consult_group'] == "N" && count($_SESSION['m_admin']['groups']['security']) < 1 )
		{
			$func->add_error(_THE_GROUP.' '._HAS_NO_SECURITY, "");
		}
		
	}
	
	/**
	* Add ou modify groups in the database
	*
	* @param string $mode up or add
	*/
	public function addupgroups($mode)
	{
		 if(file_exists($_SESSION['config']['lang'].'.php'))
		{
			include($_SESSION['config']['lang'].'.php');
		}
		else
		{
			$_SESSION['error'] = "Language file missing...<br/>";
		}
		// add ou modify users in the database
		$this->groupsinfo($mode);
		
		if(!empty($_SESSION['error']))
		{
			if($mode == "up")
			{
				if(!empty($_SESSION['m_admin']['groups']['GroupId']))
				{
					header("location: index.php?page=group_up&id=".$_SESSION['m_admin']['groups']['GroupId']);
					exit;
				}
				else
				{
					header("location: index.php?page=groups");
					exit;
				}
			}
			elseif($mode == "add")
			{
				$_SESSION['m_admin']['load_group'] = false;
				header("location: index.php?page=group_add");
				exit;
			}
		}
		else
		{
			$this->connect();
			
			if($mode == "add")
			{
				$this->query("select GROUP_ID from ".$_SESSION['tablename']['usergroups']." where GROUP_ID= '".$_SESSION['m_admin']['groups']['GroupId']."'");
				
				if($this->nb_result() > 0)
				{
					$_SESSION['error'] = $_SESSION['m_admin']['groups']['GroupId']." "._ALREADY_EXISTS."<br />";
					header("location: index.php?page=group_add");
					exit;
				}
				else
				{
					
					$this->query("INSERT INTO `".$_SESSION['tablename']['usergroups']."` (  `GROUP_ID` , `GROUP_DESC` , `ADMINISTRATOR`, 
					`CONSULT_GROUP`,  `VIEW_RELANCE`,`VIEW_STATS`, `MODIF_RIGHTS`,`EXPORT`,
					`ENABLED`, `DELETE_RIGHTS`,`DELETE_COPY_RIGHTS`, `PRINT_RIGHTS`, 
					`PRINT_SEP_RIGHTS`, `ATTACHMENT_RIGHTS`, `CLOSE_RIGHTS`, `MAIL_RIGHTS`, 
					`REJECT_RIGHTS`, `DEF_REJECT_RIGHTS`, `VALIDATE_RIGHTS`, `PARAM`, `FOLDER_RIGHTS`, `DELETE_MAIL_ACTIONS_RIGHTS`, `GDD`) 
					VALUES ( '".$_SESSION['m_admin']['groups']['GroupId']."', '".addslashes($_SESSION['m_admin']['groups']['desc'])."', 
					'".$_SESSION['m_admin']['groups']['admin']."','".$_SESSION['m_admin']['groups']['consult_group']."',  
					'".$_SESSION['m_admin']['groups']['view_relance']."',  '".$_SESSION['m_admin']['groups']['view_stats']."', 
					'".$_SESSION['m_admin']['groups']['modif_rights']."','".$_SESSION['m_admin']['groups']['export']."',  
					'Y','".$_SESSION['m_admin']['groups']['delete_rights']."','".$_SESSION['m_admin']['groups']['delete_copy_rights']."',
					'".$_SESSION['m_admin']['groups']['print_rights']."', '".$_SESSION['m_admin']['groups']['print_sep_rights']."', 
					'".$_SESSION['m_admin']['groups']['attachment_rights']."', '".$_SESSION['m_admin']['groups']['close_rights']."', 
					'".$_SESSION['m_admin']['groups']['mail_rights']."', '".$_SESSION['m_admin']['groups']['reject_rights']."', 
					'".$_SESSION['m_admin']['groups']['def_reject_rights']."', '".$_SESSION['m_admin']['groups']['validate_rights']."', 
					'".$_SESSION['m_admin']['groups']['param']."', '".$_SESSION['m_admin']['groups']['folder_rights']."', '".$_SESSION['m_admin']['groups']['delete_mail_actions_rights']."', '".$_SESSION['m_admin']['groups']['gdd']."')");
					
					if($_SESSION['m_admin']['groups']['consult_group'] == 'N')
					{
						require_once("class_security.php");
						$sec = new security();
						$syntax = true;
						
						$syntax =  $sec->where_test();

						 if($syntax <> true)
						 {
						 	$_SESSION['error'] .= " : "._SYNTAX_ERROR_WHERE_CLAUSE."." ;
							header("location: index.php?page=group_up&id=".$_SESSION['m_admin']['groups']['GroupId']);
							exit;
						 }
						 else
						 {
							$sec->load_db();
					
							if($_SESSION['history']['usergroupsadd'] == "true")
							{
								require_once("class_history.php");
								$users = new history();
								$users->add($_SESSION['tablename']['usergroups'], $_SESSION['m_admin']['groups']['GroupId'],"ADD",_GROUP_ADDED." : ".$_SESSION['m_admin']['groups']['GroupId']);
							}
						
							$this->cleargroupinfos();
					
							$_SESSION['error'] = _GROUP_ADDED;
							header("location: index.php?page=groups");
							exit;
						 }
					 }
					 else
					 {
						require_once("class_letterbox.php");
						
						$LB = new LetterBox();
						
						$LB->load_group_service();
						
						if($_SESSION['history']['usergroupsadd'] == "true")
						{
							require_once("class_history.php");
							$users = new history();
							$users->add($_SESSION['tablename']['usergroups'], $_SESSION['m_admin']['groups']['GroupId'],"ADD",_GROUP_ADDED." : ".$_SESSION['m_admin']['groups']['GroupId']);
						}
						
						$this->cleargroupinfos();
					
						$_SESSION['error'] = _GROUP_ADDED;
						header("location: index.php?page=groups");
						exit;
					 }
				 }
			}
			elseif($mode == "up")
			{
				
				$this->query("UPDATE `".$_SESSION['tablename']['usergroups']."` set `GROUP_DESC` = '".addslashes($_SESSION['m_admin']['groups']['desc'])."' , 
				`ADMINISTRATOR` = '".$_SESSION['m_admin']['groups']['admin']."', `CONSULT_GROUP` = '".$_SESSION['m_admin']['groups']['consult_group']."', 
				`VIEW_RELANCE` = '".$_SESSION['m_admin']['groups']['view_relance']."', `VIEW_STATS` = '".$_SESSION['m_admin']['groups']['view_stats']."' ,
				`EXPORT` = '".$_SESSION['m_admin']['groups']['export']."',`MODIF_RIGHTS` = '".$_SESSION['m_admin']['groups']['modif_rights']."',
				`DELETE_RIGHTS` = '".$_SESSION['m_admin']['groups']['delete_rights']."',
				`DELETE_COPY_RIGHTS` = '".$_SESSION['m_admin']['groups']['delete_copy_rights']."',
				`DELETE_MAIL_ACTIONS_RIGHTS` = '".$_SESSION['m_admin']['groups']['delete_mail_actions_rights']."',
				`PRINT_RIGHTS` = '".$_SESSION['m_admin']['groups']['print_rights']."', 
				`PRINT_SEP_RIGHTS` = '".$_SESSION['m_admin']['groups']['print_sep_rights']."', 
				`ATTACHMENT_RIGHTS` = '".$_SESSION['m_admin']['groups']['attachment_rights']."', `CLOSE_RIGHTS` = '".$_SESSION['m_admin']['groups']['close_rights']."', 
				`MAIL_RIGHTS` = '".$_SESSION['m_admin']['groups']['mail_rights']."', `REJECT_RIGHTS` = '".$_SESSION['m_admin']['groups']['reject_rights']."', 
				`DEF_REJECT_RIGHTS` = '".$_SESSION['m_admin']['groups']['def_reject_rights']."', `VALIDATE_RIGHTS` = '".$_SESSION['m_admin']['groups']['validate_rights']."', 
				`GDD` = '".$_SESSION['m_admin']['groups']['gdd']."', 
				PARAM = '".$_SESSION['m_admin']['groups']['param']."', FOLDER_RIGHTS = '".$_SESSION['m_admin']['groups']['folder_rights']."' 
				
				where GROUP_ID = '".$_SESSION['m_admin']['groups']['GroupId']."'");
				
					if($_SESSION['m_admin']['groups']['consult_group'] == 'N')
					{
						require_once("class_security.php");
						$sec = new security();
					
						if( $sec->where_test() == false)
						 {
					 		$_SESSION['error'] .= " : "._SYNTAX_ERROR_WHERE_CLAUSE."." ;
							header("location: index.php?page=group_up&id=".$_SESSION['m_admin']['groups']['GroupId']);
							exit;
						}
						else
						{
							$sec->load_db();
					
							if($_SESSION['history']['usergroupsup'] == "true")
							{
								require_once("class_history.php");
								$users = new history();
								$users->add($_SESSION['tablename']['usergroups'], $_SESSION['m_admin']['groups']['GroupId'],"UP",_GROUP_UPDATE." : ".$_SESSION['m_admin']['groups']['GroupId']);
							}
						
							if($this->in_group($_SESSION['user']['UserId'], $_SESSION['m_admin']['groups']['GroupId']) )
							{
								require_once("class_users.php");
								$_SESSION['user']['groups'] = array();
								$_SESSION['user']['security'] = array();
								$user = new users();
								$tmp = $user->load_groups($_SESSION['user']['UserId']);
								$_SESSION['user']['primarygroup']= $tmp[0];
								$_SESSION['user']['groups'] = $tmp[1];
								$arr_sec = $user->load_security($_SESSION['user']['UserId']);
								$_SESSION['user']['tables'] = $arr_sec['tables'];
								$_SESSION['user']['security'] = $arr_sec['security'];
								$_SESSION['user']['can_index'] = $arr_sec['can_index'];
								$_SESSION['user']['can_postindex'] = $arr_sec['can_postindex'];
							}

							$this->cleargroupinfos();
													
							$_SESSION['error'] = _GROUP_UPDATED;
							header("location: index.php?page=groups");
							exit;
						}
					}
					else
					{
						require_once("class_letterbox.php");
						
						$LB = new LetterBox();
						
						$LB->load_group_service();
						
						if($_SESSION['history']['usergroupsup'] == "true")
						{
							require_once("class_history.php");
							$users = new history();
							$users->add($_SESSION['tablename']['usergroups'], $_SESSION['m_admin']['groups']['GroupId'],"UP",_GROUP_UPDATE." : ".$_SESSION['m_admin']['groups']['GroupId']);
						}
						
						if($this->in_group($_SESSION['user']['UserId'], $_SESSION['m_admin']['groups']['GroupId']) )
						{
							require_once("class_users.php");
							$_SESSION['user']['groups'] = array();
							$_SESSION['user']['security'] = array();
							$user = new users();
							$tmp = $user->load_groups($_SESSION['user']['UserId']);
							$_SESSION['user']['primarygroup']= $tmp[0];
							$_SESSION['user']['groups'] = $tmp[1];
							$arr_sec = $user->load_security($_SESSION['user']['UserId']);
							$_SESSION['user']['tables'] = $arr_sec['tables'];
							$_SESSION['user']['security'] = $arr_sec['security'];
							$_SESSION['user']['can_index'] = $arr_sec['can_index'];
							$_SESSION['user']['can_postindex'] = $arr_sec['can_postindex'];
						}
						$this->cleargroupinfos();
													
						$_SESSION['error'] = _GROUP_UPDATED;
						header("location: index.php?page=groups");
						exit;
					}
			}
		}
	}
	
	/**
	* Tests if the user belong to the group
	*
	* @param string $user user identifier
	* @param string $group group identifier
	*/
	private function in_group($user, $group)
	{
		$this->connect();
		$this->query("select count(*) from ".$_SESSION['tablename']['usergroup_content']." where USER_ID ='".$user."' and GROUP_ID = '".$group."'");
		
		if($this->nb_result() > 0)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	* Clear the $_SESSION['m_admin']['groups'] variable
	*
	*/
	private function cleargroupinfos()
		{
			// clear the users add or modification vars
			$_SESSION['m_admin']['groups'] = array();
			$_SESSION['m_admin']['groups']['GroupId'] = "";
			$_SESSION['m_admin']['groups']['desc'] = "";
			$_SESSION['m_admin']['groups']['admin'] = "";
			$_SESSION['m_admin']['groups']['view_relance'] = "";
			$_SESSION['m_admin']['groups']['view_stats'] = "";
			$_SESSION['m_admin']['groups']['modif_rights'] = "";
			$_SESSION['m_admin']['groups']['security'] = array();
			$_SESSION['m_admin']['groups']['consult_group'] = "";
			$_SESSION['m_admin']['groups']['export'] = "";
			$_SESSION['m_admin']['groups']['delete_rights'] = "";
			$_SESSION['m_admin']['groups']['delete_copy_rights'] = "";
			$_SESSION['m_admin']['groups']['print_rights'] = "";
			$_SESSION['m_admin']['groups']['print_sep_rights'] = "";
			$_SESSION['m_admin']['groups']['attachment_rights'] = "";
			$_SESSION['m_admin']['groups']['close_rights'] = "";
			$_SESSION['m_admin']['groups']['mail_rights'] = "";
			$_SESSION['m_admin']['groups']['reject_rights'] = "";
			$_SESSION['m_admin']['groups']['def_reject_rights'] = "";
			$_SESSION['m_admin']['groups']['validate_rights'] = "";
			$_SESSION['m_admin']['groups']['param'] = '';
			$_SESSION['m_admin']['groups']['folder_rights'] = "";
			$_SESSION['m_admin']['groups']['delete_mail_actions_rights'] = "";
			$_SESSION['m_admin']['groups']['gdd'] = "";
			$_SESSION['services_choisis'] = array();
		}
		
	/**
	* Add ou modify groups in the database
	*
	* @param string $id group identifier
	* @param string $mode up or add
	*/
	public function admingroup($id,$mode)
	{
		if(!empty($_SESSION['error']))
		{
			header("location: index.php?page=groups");
			exit;
		}
		else
		{
			$this->connect();
			
			$this->query("select GROUP_ID from ".$_SESSION['tablename']['usergroups']." where GROUP_ID = '".$id."'");
			
			if($this->nb_result() == 0)
			{
				$_SESSION['error'] = _GROUP.' '._UNKNWON;
				header("location: index.php?page=groups");
				exit;
			}
			else
			{
				$info = $this->fetch_object();
				$theuser = $info->LastName." ".$info->FirstName." (".$id.")";
				
				if($mode == "allow")
				{
					$this->query("Update ".$_SESSION['tablename']['usergroups']." set enabled = 'Y' where group_id = '".$id."'");
					if($_SESSION['history']['usergroupsval'] == "true")
					{
						require_once("class_history.php");
						$users = new history();
						$users->add($_SESSION['tablename']['usergroups'], $id,"VAL",_GROUP_AUTORIZATION." : ".$id);
					}
					$_SESSION['error'] = _AUTORIZED_GROUP;
					
					if($this->in_group($_SESSION['user']['UserId'], $id))
					{
						require_once("class_users.php");
						$user = new users();
						$tmp = $user->load_groups($_SESSION['user']['UserId']);
						$_SESSION['user']['primarygroup']= $tmp[0];
						$_SESSION['user']['groups'] = $tmp[1];
						$arr_sec = $user->load_security($_SESSION['user']['UserId']);
						$_SESSION['user']['tables'] = $arr_sec['tables'];
						$_SESSION['user']['security'] = $arr_sec['security'];
						$_SESSION['user']['can_index'] = $arr_sec['can_index'];
						$_SESSION['user']['can_postindex'] = $arr_sec['can_postindex'];
					}
					
				}
				elseif($mode == "ban")
				{
					$this->query("Update ".$_SESSION['tablename']['usergroups']." set enabled = 'N' where group_id = '".$id."'");
					if($_SESSION['history']['usergroupsban'] == "true")
					{
						require_once("class_history.php");
						$users = new history();
						$users->add($_SESSION['tablename']['usergroups'], $id,"BAN",_GROUP_SUSPENSION." : ".$id);
					}
					$_SESSION['error'] = _SUSPENDED_GROUP;
					
					if($this->in_group($_SESSION['user']['UserId'], $id))
					{
						require_once("class_users.php");
						$user = new users();
						$tmp = $user->load_groups($_SESSION['user']['UserId']);
						$_SESSION['user']['primarygroup']= $tmp[0];
						$_SESSION['user']['groups'] = $tmp[1];
						$arr_sec = $user->load_security($_SESSION['user']['UserId']);
						$_SESSION['user']['tables'] = $arr_sec['tables'];
						$_SESSION['user']['security'] = $arr_sec['security'];
						$_SESSION['user']['can_index'] = $arr_sec['can_index'];
						$_SESSION['user']['can_postindex'] = $arr_sec['can_postindex'];
					}
				}
				elseif($mode == "del" )
				{
					$this->query("delete from ".$_SESSION['tablename']['usergroups']."  where group_id = '".$id."'");
					$this->query("delete from ".$_SESSION['tablename']['usergroup_content']."  where group_id = '".$id."'");
					$this->query("delete from ".$_SESSION['tablename']['security']."  where group_id = '".$id."'");
					
					if($_SESSION['history']['usergroupsdel'] == "true")
					{
						require_once("class_history.php");
						$users = new history();
						$users->add($_SESSION['tablename']['usergroups'], $id,"DEL",_GROUP_DELETION." : ".$id);
					}
					$_SESSION['error'] = _DELETED_GROUP;					
					
					if($this->in_group($_SESSION['user']['UserId'], $id))
					{
						require_once("class_users.php");
						$user = new users();
						$tmp = $user->load_groups($_SESSION['user']['UserId']);
						$_SESSION['user']['primarygroup']= $tmp[0];
						$_SESSION['user']['groups'] = $tmp[1];
						$arr_sec = $user->load_security($_SESSION['user']['UserId']);
						$_SESSION['user']['tables'] = $arr_sec['tables'];
						$_SESSION['user']['security'] = $arr_sec['security'];
						$_SESSION['user']['can_index'] = $arr_sec['can_index'];
						$_SESSION['user']['can_postindex'] = $arr_sec['can_postindex'];
					}
				}
				
				header("location: index.php?page=groups");
				exit;
			}
		}
	}
	
}

?>
