var Maarch = {
    REQUIRED_PROTOTYPE: '1.6.0.2',

    load: function(){
        function convertVersionString(versionString){
          var r = versionString.split('.');
          return parseInt(r[0])*1000000 + parseInt(r[1])*10000 + parseInt(r[2])*100 + (r[3] ? parseInt(r[3]) : 0);
        }

        if((typeof Prototype=='undefined') ||
           (typeof Element == 'undefined') ||
           (typeof Element.Methods=='undefined') ||
           (convertVersionString(Prototype.Version) <
            convertVersionString(Maarch.REQUIRED_PROTOTYPE)))
           throw("Maarch.js requires the Prototype JavaScript framework >= " +
            Maarch.REQUIRED_PROTOTYPE);

        Maarch._fixPrototype();
    },

    url: (function(){
        return $$('script').find(function(el){
            return el.src.match(/MaarchTree\.js$/);
        }).src.replace(/(.*)MaarchTree\.js/, "$1");
    })(),

    _fixPrototype: function(){
        //If method on is not defined for Element objects
        if (!Element.on){
            //we create it
            function on(element, event, selector, callback){
                var element = $(element);
                if (Object.isFunction(selector) && Object.isUndefined(callback)) {
                  callback = selector, selector = null;
                }
                if (selector){
                    var new_callback = function(evt){
                        var elt = evt.findElement(selector) || document;
                        if (elt != document){
                            callback(evt, elt);
                        }
                    }
                } else {
                    var new_callback = function(evt){
                        callback(evt);
                    }
                }
                element.observe(event, new_callback);
            }

            Element.addMethods({
                on: on
            });
        }
    },

    injectCSS: function(stylesheet){
        if ($$('link[rel=stylesheet]').find(function(el){
            return el.href.match(new RegExp(stylesheet+'\.css$'));
        }) == undefined){
            $(document.body).insert({bottom: new Element('link', {
                rel: 'stylesheet',
                href: Maarch.url + stylesheet + '.css',
                type: "text/css"
            })});
        }
    },

    AddIEDiv: function(element){
        if (Prototype.Browser.IE){
            var element = $(element);
            element.wrap(new Element("div", {id: "IE"+navigator.appVersion.replace(/.*MSIE ([6-8]).*/, '$1')}));
        }
    }

};

Maarch.treeView = {

    Tree: Class.create({
        _DEFAULT_OPTIONS: {
            'treeId' : 'MaarchTree',
            'treeLabel': 'MaarchTree',
            'img.path': 'img/',
            'img.mt_fopened': 'folderopen.gif',
            'img.mt_fclosed': 'folder.gif',
            'img.mt_plus': 'plus0.gif',
            'img.mt_minus': 'minus0.gif',
            'img.mt_none': 'none.gif'

        },

        _setOptions: function(params){
            var options = this._DEFAULT_OPTIONS;
            var list_keys = $H(this._DEFAULT_OPTIONS).keys().intersect($H(params).keys());
            list_keys.each(function(el){
                options[el] = params[el];
            });
            this.options = options;
        },

        // Initialisation de l'arbre
        initialize : function(div, branches_values, params){
            this.root = $(div).addClassName('MaarchTreeRoot');

            Maarch.AddIEDiv(this.root);
            Maarch.injectCSS('MaarchTree');


            this.prefix = "mt_" + this.root.id + "_"
            // this.imgs.mt_leaf = params['imgs']['mt_leaf'];
            this._setOptions(params);

            // construction
            this.insertBranches(branches_values, this.root);

            //Déclaration des événements à observer
            this._setEventObserver();

        },

    /****************** Navigation Methods *******************/

        // retourne une branche
        getBranchById : function(branch_id){
            return $(branch_id);
        },

        hasChild: function(branch_id)
        {
            return $(branch_id).down('li') ? true : false;
        },

    /****************** Branches control Methods *******************/

        // ouvre une branche
        expand : function(branch_id){
            var branch = $(branch_id);
            branch.removeClassName('mt_closed');
            branch.addClassName('mt_opened');
            if(!this.hasChild(branch))
            {
                branch.addClassName('mt_leaf');
            }
            return branch;
        },

        // ferme une branche
        collapse : function(branch_id){
            var branch = $(branch_id);
            branch.removeClassName('mt_opened');
            branch.addClassName('mt_closed');
            return branch;
        },


        toggle : function(branch_id){
            var branch = $(branch_id);
            this[branch.hasClassName('mt_opened') ? 'collapse' : 'expand'](branch_id);
            return branch;
        },

        // Insert une nouvelle branche
        insertBranches : function(branches_values, parent_branch_id){
            // TO DO : try-catch
            var parent = this.getBranchById(parent_branch_id);
            var node = this._createNode(parent);

            branches_values.each(function(el){
                // Bug sur les id commençant par des chiffres dans prototype 1.6
                // pour éviter les conflits d'identifiants
                el.id = this.prefix + el.id;
                var new_branch = this._createBranch(el);
                node.insert(new_branch); // TO DO : gestion de la position
                if (el.children && el.children.length > 0){
                    this.insertBranches(el.children, el.id);
                }

            }.bind(this));

        },

        _createNode : function(parent_id)
        {
            var parent = $(parent_id);
            var node = parent.down('ul');
            if (!node)
            {
                node = new Element('ul').wrap(parent);
                node = node.down('ul');
            }
            return node;
        },

        _createBranch : function(el)
        {
            //creation du li
            var branch = new Element('li',{'id' : el.id, 'class': 'mt_closed'});
            var span = new Element("span").insert(el.label);
            // Img dossier
            span.insert({
                top: new Element("img",
                                 {'src': this.options['img.path'] + this.options['img.mt_fopened'],
                                  'class' : 'mt_fopened',
                                  'alt' : ''})});
            span.insert({
                top: new Element("img",
                                 {'src': this.options['img.path'] + this.options['img.mt_fclosed'],
                                  'class' : 'mt_fclosed',
                                  'alt' : ''})});
            span.insert({
                top: new Element("img",
                                 {'src': this.options['img.path'] + this.options['img.mt_plus'],
                                  'class' : 'mt_plus',
                                   'alt' : ''})});
            span.insert({
                top: new Element("img",
                                 {'src': this.options['img.path'] + this.options['img.mt_minus'],
                                  'class' : 'mt_minus',
                                  'alt' : ''})});
            span.insert({
                top: new Element("img",
                                 {'src': this.options['img.path'] + this.options['img.mt_none'],
                                  'class' : 'mt_none',
                                  'alt' : ''})});
            branch.insert({top: span});
            return branch;
        },

        select : function(branch_id)
        {
            var branch = $(branch_id);
            $$('.mt_selected').each(this.deselect.bind(this));
            branch.addClassName('mt_selected');
            this.expand(branch);
            branch.fire("maarch:tree:branchselect", {"branch_id": branch.id.replace(new RegExp(this.prefix + "(.*)"), "$1")});
            return branch;
        },

        deselect : function(branch_id)
        {
            var branch = $(branch_id);
            branch.removeClassName('mt_selected');
            if(branch.hasClassName('mt_leaf'))
            {
                this.collapse(branch);
            }
            return branch;
        },

    /****************** Others Methods *******************/

        //Déclaration d'événements
        _setEventObserver: function()
        {
            this.root.on("click", ".mt_plus, .mt_minus, li", function(evt, elt){
                if (elt.tagName == "LI"){
                    this.select(elt);
                } else {
                    var elt = elt.up('li');
                    this.toggle(elt);
                }
            }.bind(this));
        }
    }),


    /************** Optional features **********************/
    activateToolTip: function()
    {
        var _old_createBranch = Maarch.treeView.Tree.prototype._createBranch;
        Maarch.treeView.Tree.addMethods({
            _createBranch : function(branch_infos){
                var branch = _old_createBranch.bind(this)(branch_infos);
                var span_container = branch.down("span");
                span_container.writeAttribute("title",
                                              branch_infos.toolTip || '')
                return branch;
            }
        });
    },

    activateAjaxLoad: function()
    {
        var old_expand = Maarch.treeView.Tree.prototype.expand;

        Maarch.treeView.Tree.addMethods({
            expand : function(el){
                var branch = old_expand.bind(this)(el);
                if(!branch.down('ul'))
                {
                    new Ajax.Request('test.php',{
                        method: 'post',
                        parameters: {
                            parent_id : branch.id.replace(new RegExp(this.prefix + "(\.*)"), "$1")
                        },
                        onSuccess: function(response){
                            eval('struct='+response.responseText+';');
                            if(struct.length > 0)
                            {
                                this.insertBranches(struct, branch.id);
                                branch.removeClassName('mt_leaf');
                            }
                        }.bind(this)
                    });
                }
                return branch;
            }
        });

    }

};

Maarch.load();